==> wfde-3.01.09.tar.gz: wfde-3.01.09/cpplib/WarIfPathList.cpp <==
#include "StdAfx.h"
#include "WarIfPathList.h"   // class implemented


/////////////////////////////// PUBLIC ///////////////////////////////////////

//============================= LIFECYCLE ====================================

WarIfPathList::WarIfPathList(const WarWin32Registry& regKey)
{
    // Open registry key
    mRegKey.Create(regKey.GetRootKey(), 
        regKey.GetPath(WAR_WINNT_REG_FILE_SYSTEMS));
    
}// WarIfPathList

WarIfPathList::~WarIfPathList()
{
}// ~WarIfPathList


//============================= OPERATORS ====================================
//============================= OPERATIONS ===================================

void WarIfPathList::EnumPaths(war_svr_pathset_t& pathSet, 
                              bool doReplace)
                              throw(WarException)
{
    WarWin32Registry reg_fsys;
    WarWin32Registry::keyname_list_t file_systems;
    WarWin32Registry::keyname_list_t::const_iterator P;

    mRegKey.EnumKey(file_systems);

    for(P = file_systems.begin()
        ; P != file_systems.end()
        ; P++)
    {
        reg_fsys.Open(HKEY_LOCAL_MACHINE, 
            mRegKey.GetPath(P->c_str()), KEY_READ);
        
        DWORD perms = reg_fsys.GetIntValue(WAR_WINNT_REG_PERMISSIONS);
        WarUtf8 mount_point = P->c_str();
        WarUtf8 url = reg_fsys.GetStrValue(WAR_WINNT_SHARE_URL);

        WarSvrPath new_path(mount_point.GetUtf8().c_str(), 
            url.GetUtf8().c_str(), perms);

#if WAR_RFC2577
        // IP Access List
        war_regstr_t ip_list_str = reg_fsys.GetStrValue(WAR_WINNT_REG_IP_ACCESS_LIST);
        WarIpAccessList::ModeE ip_list_mode = (WarIpAccessList::ModeE)reg_fsys.GetIntValue(WAR_WINNT_REG_IP_ACCESS_LIST_MODE, 0);
        if (ip_list_mode != WarIpAccessList::DEFAULT_DENY)
            ip_list_mode = WarIpAccessList::DEFAULT_ALLOW;
        WarIpAccessList my_access_list;
        my_access_list.SetValue(ip_list_mode, ip_list_str.c_str());
        new_path.SetIpAccessList(my_access_list);
#endif

        if (doReplace)
        {
            // Remove the path from the effectiveProperties if it
            // already exist
            war_svr_pathset_t::iterator P 
                = pathSet.find(new_path);
            if (P != pathSet.end())
                pathSet.erase(P);
        }
        
        pathSet.insert(new_path);
    }
}

//============================= ACCESS     ===================================
//============================= INQUIRY    ===================================
/////////////////////////////// PROTECTED  ///////////////////////////////////

/////////////////////////////// PRIVATE    ///////////////////////////////////

==> wfde-3.01.10.tar.gz: wfde-3.01.10/cpplib/WarIfPathList.cpp <==
#include "StdAfx.h"
#include "WarIfPathList.h"   // class implemented


/////////////////////////////// PUBLIC ///////////////////////////////////////

//============================= LIFECYCLE ====================================

WarIfPathList::WarIfPathList(const WarWin32Registry& regKey)
{
    // Open registry key
    mRegKey.Create(regKey.GetRef(WAR_WINNT_REG_FILE_SYSTEMS));
    
}// WarIfPathList

WarIfPathList::~WarIfPathList()
{
}// ~WarIfPathList


//============================= OPERATORS ====================================
//============================= OPERATIONS ===================================

void WarIfPathList::EnumPaths(war_svr_pathset_t& pathSet, 
                              bool doReplace)
                              throw(WarException)
{
    WarWin32Registry reg_fsys;
    WarWin32Registry::keyname_list_t file_systems;
    WarWin32Registry::keyname_list_t::const_iterator P;

    mRegKey.EnumKey(file_systems);

    for(P = file_systems.begin()
        ; P != file_systems.end()
        ; P++)
    {
        reg_fsys.Open(mRegKey.GetRef(P->c_str()), KEY_READ);
        
        DWORD perms = reg_fsys.GetIntValue(WAR_WINNT_REG_PERMISSIONS);
        WarUtf8 mount_point = P->c_str();
        WarUtf8 url = reg_fsys.GetStrValue(WAR_WINNT_SHARE_URL, 
            NULL, false, true);

        WarSvrPath new_path(mount_point.GetUtf8().c_str(), 
            url.GetUtf8().c_str(), perms);

#if WAR_RFC2577
        // IP Access List
        war_regstr_t ip_list_str = reg_fsys.GetStrValue(WAR_WINNT_REG_IP_ACCESS_LIST);
        WarIpAccessList::ModeE ip_list_mode = (WarIpAccessList::ModeE)reg_fsys.GetIntValue(WAR_WINNT_REG_IP_ACCESS_LIST_MODE, 0);
        if (ip_list_mode != WarIpAccessList::DEFAULT_DENY)
            ip_list_mode = WarIpAccessList::DEFAULT_ALLOW;
        WarIpAccessList my_access_list;
        my_access_list.SetValue(ip_list_mode, ip_list_str.c_str());
        new_path.SetIpAccessList(my_access_list);
#endif

        if (doReplace)
        {
            // Remove the path from the effectiveProperties if it
            // already exist
            war_svr_pathset_t::iterator P = pathSet.find(new_path);
            if (P != pathSet.end())
                pathSet.erase(P);
        }
        
        pathSet.insert(new_path);
    }
}

//============================= ACCESS     ===================================
//============================= INQUIRY    ===================================
/////////////////////////////// PROTECTED  ///////////////////////////////////

/////////////////////////////// PRIVATE    ///////////////////////////////////
